Learn R Programming

Certara.DarwinReporter (version 2.0.1)

darwinReportUI: Generate and Report Model Diagnostics from NLME or NONMEM runs

Description

Shiny application to generate, customize, and report diagnostic plots and tables from NLME or NONMEM output files. Create an Rmarkdown file of tagged model diagnostics and render into submission ready report.

Usage

darwinReportUI(darwin_data, tagged = NULL, settings = NULL, ...)

Value

If interactive(), returns a list of tagged diagnostics from the Shiny application, otherwise returns TRUE.

Arguments

darwin_data

Object of class darwin_data. Note, key_models xpose_data must be available.

tagged

List of tagged objects returned from previous tagged <- darwinReportUI() session.

settings

List of settings (e.g., settings.Rds) returned from previous Shiny session.

...

Additional arguments for Pirana integration.

Examples

Run this code
if (interactive()) {
ddb <- darwin_data("./darwin_search_09") |>
   import_key_models("./darwin_search_09/key_models")

darwinReportUI(ddb)
}

Run the code above in your browser using DataLab